@@ -18,14 +18,12 @@ import warnings
 from Cheetah import five
 from Cheetah.legacy_parser import LegacyParser
 from Cheetah.legacy_parser import SET_GLOBAL
-from Cheetah.legacy_parser import SET_MODULE
 from Cheetah.legacy_parser import escapedNewlineRE
 from Cheetah.SettingsManager import SettingsManager
 
 
-FilterDetails = collections.namedtuple('FilterDetails', ['ID', 'theFilter'])
 CallDetails = collections.namedtuple(
-    'CallDetails', ['ID', 'functionName', 'args', 'lineCol'],
+    'CallDetails', ['call_id', 'function_name', 'args', 'lineCol'],
 )
 
 
@@ -131,7 +129,6 @@ class GenUtils(object):
         where:
           VFN = NameMapper.valueForName
           VFFSL = NameMapper.valueFromFrameOrSearchList
-          VFSL = NameMapper.valueFromSearchList # optionally used instead of VFFSL
           SL = self.searchList()
           useAC = self.setting('useAutocalling') # True in this example
 
@@ -190,21 +187,19 @@ class MethodCompiler(GenUtils):
         self._indent = self.setting('indentationStep')
         self._indentLev = 2
         self._pendingStrConstChunks = []
-        self._methodSignature = None
         self._methodBodyChunks = []
         self._callRegionsStack = []
         self._filterRegionsStack = []
         self._hasReturnStatement = False
         self._isGenerator = False
-        self._argStringList = [("self", None)]
+        self._argStringList = [('self', None)]
         self._decorators = decorators or []
 
     def setting(self, key):
         return self._settingsManager.setting(key)
 
     def cleanupState(self):
-        """Called by the containing class compiler instance
-        """
+        """Called by the containing class compiler instance"""
         self.commitStrConst()
 
         has_double_star_arg = any(
@@ -212,6 +207,7 @@ class MethodCompiler(GenUtils):
             for argname, _ in self._argStringList
         )
 
+        # TODO: make it not so
         if not has_double_star_arg:
             self.addMethArg('**KWS', None)
 
@@ -245,12 +241,11 @@ class MethodCompiler(GenUtils):
 
     def methodDef(self):
         self.commitStrConst()
-        methodDefChunks = (
+        return ''.join((
             self.methodSignature(),
             '\n',
-            self.methodBody())
-        methodDef = ''.join(methodDefChunks)
-        return methodDef
+            self.methodBody(),
+        ))
 
     def methodBody(self):
         return ''.join(self._methodBodyChunks)
@@ -259,30 +254,26 @@ class MethodCompiler(GenUtils):
 
     def addChunk(self, chunk):
         self.commitStrConst()
-        chunk = "\n" + self.indentation() + chunk
+        chunk = '\n' + self.indentation() + chunk
         self._methodBodyChunks.append(chunk)
 
     def appendToPrevChunk(self, appendage):
-        self._methodBodyChunks[-1] = self._methodBodyChunks[-1] + appendage
+        self._methodBodyChunks[-1] += appendage
 
     def addWriteChunk(self, chunk):
-        self.addChunk('write(' + chunk + ')')
+        self.addChunk('write({0})'.format(chunk))
 
     def addFilteredChunk(self, chunk, rawExpr=None, lineCol=None):
         if rawExpr and rawExpr.find('\n') == -1 and rawExpr.find('\r') == -1:
-            self.addChunk("_v = %s # %r" % (chunk, rawExpr))
-            assert lineCol
+            self.addChunk('_v = {0} # {1!r}'.format(chunk, rawExpr))
             self.appendToPrevChunk(' on line %s, col %s' % lineCol)
         else:
-            self.addChunk("_v = %s" % chunk)
+            self.addChunk('_v = %s' % chunk)
 
-        self.addChunk("if _v is not NO_CONTENT: write(_filter(_v))")
+        self.addChunk('if _v is not NO_CONTENT: write(_filter(_v))')
 
     def addStrConst(self, strConst):
-        if self._pendingStrConstChunks:
-            self._pendingStrConstChunks.append(strConst)
-        else:
-            self._pendingStrConstChunks = [strConst]
+        self._pendingStrConstChunks.append(strConst)
 
     def commitStrConst(self):
         """Add the code for outputting the pending strConst without chopping off
@@ -331,40 +322,29 @@ class MethodCompiler(GenUtils):
         self.addFilteredChunk(expr, rawPlaceholder, lineCol)
         self.appendToPrevChunk(' # from line %s, col %s' % lineCol + '.')
 
-    def addSet(self, expr, exprComponents, setStyle):
+    def addSet(self, components, setStyle):
+        expr = ' '.join([component.strip() for component in components])
         if setStyle is SET_GLOBAL:
-            (LVALUE, OP, RVALUE) = (exprComponents.LVALUE,
-                                    exprComponents.OP,
-                                    exprComponents.RVALUE)
-            # we need to split the LVALUE to deal with globalSetVars
-            splitPos1 = LVALUE.find('.')
-            splitPos2 = LVALUE.find('[')
-            if splitPos1 > 0 and splitPos2 == -1:
-                splitPos = splitPos1
-            elif splitPos1 > 0 and splitPos1 < max(splitPos2, 0):
-                splitPos = splitPos1
-            else:
-                splitPos = splitPos2
+            # we need to split the lvalue to deal with globalSetVars
+            first_obj_match = re.search(r'[\[\.]', components.lvalue)
+            split_pos = first_obj_match.start() if first_obj_match else -1
 
-            if splitPos > 0:
-                primary = LVALUE[:splitPos]
-                secondary = LVALUE[splitPos:]
+            if split_pos > 0:
+                primary = components.lvalue[:split_pos]
+                secondary = components.lvalue[split_pos:]
             else:
-                primary = LVALUE
+                primary = components.lvalue
                 secondary = ''
-            LVALUE = 'self._CHEETAH__globalSetVars["' + primary + '"]' + secondary
-            expr = LVALUE + ' ' + OP + ' ' + RVALUE.strip()
+            expr = 'self._CHEETAH__globalSetVars["{0}"]{1} {2} {3}'.format(
+                primary, secondary, components.op, components.rvalue,
+            )
 
-        if setStyle is SET_MODULE:
-            self._moduleCompiler.addModuleGlobal(expr)
-        else:
-            self.addChunk(expr)
+        self.addChunk(expr)
 
     def addIndentingDirective(self, expr, lineCol):
-        assert expr and expr[-1] != ':'
+        assert expr[-1] != ':'
         expr = expr + ':'
         self.addChunk(expr)
-        assert lineCol
         self.appendToPrevChunk(' # generated from line %s, col %s' % lineCol)
         self.indent()
 
@@ -419,70 +399,78 @@ class MethodCompiler(GenUtils):
         for line in PSP.splitlines():
             self.addChunk(line)
 
-    def nextCacheID(self):
+    def next_id(self):
         self._next_variable_id += 1
         return '_{0}'.format(self._next_variable_id)
 
-    nextCallRegionID = nextCacheID
+    def startCallRegion(self, function_name, args, lineCol):
+        call_id = self.next_id()
+        call_details = CallDetails(call_id, function_name, args, lineCol)
+        self._callRegionsStack.append(call_details)
 
-    def startCallRegion(self, functionName, args, lineCol):
-        call_id = self.nextCallRegionID()
-        call_details = CallDetails(call_id, functionName, args, lineCol)
-
-        self._callRegionsStack.append((call_id, call_details))
-
-        self.addChunk('## START CALL REGION: '
-                      + call_id
-                      + ' of ' + functionName
-                      + ' at line %s, col %s' % lineCol + ' in the source.')
+        self.addChunk(
+            '## START CALL REGION: {call_id} of {function_name} '
+            'at line {line}, col {col}.'.format(
+                call_id=call_id,
+                function_name=function_name,
+                line=lineCol[0],
+                col=lineCol[1],
+            )
+        )
         self.addChunk('_orig_trans{0} = trans'.format(call_id))
-        self.addChunk('trans = _callCollector{0} = DummyTransaction()'.format(
-            call_id,
-        ))
-        self.addChunk('self.transaction = trans')
-        self.addChunk('write = _callCollector{0}.response().write'.format(
-            call_id,
-        ))
+        self.addChunk(
+            'self.transaction = trans = _call{0} = DummyTransaction()'.format(
+                call_id
+            )
+        )
+        self.addChunk('write = trans.response().write')
 
     def endCallRegion(self):
-        ID, callDetails = self._callRegionsStack[-1]
-        functionName, initialKwArgs, lineCol = (
-            callDetails.functionName, callDetails.args, callDetails.lineCol)
+        call_details = self._callRegionsStack.pop()
+        call_id, function_name, args, (line, col) = (
+            call_details.call_id,
+            call_details.function_name,
+            call_details.args,
+            call_details.lineCol,
+        )
 
-        def reset(ID=ID):
-            self.addChunk('trans = _orig_trans{0}'.format(ID))
-            self.addChunk('self.transaction = trans')
-            self.addChunk('write = trans.response().write')
-            self.addChunk('del _orig_trans{0}'.format(ID))
+        self.addChunk(
+            'self.transaction = trans = _orig_trans{0}'.format(call_id),
+        )
+        self.addChunk('write = trans.response().write')
+        self.addChunk('del _orig_trans{0}'.format(call_id))
 
-        reset()
-        self.addChunk('_callArgVal%(ID)s = _callCollector%(ID)s.response().getvalue()' % locals())
-        self.addChunk('del _callCollector%(ID)s' % locals())
-        if initialKwArgs:
-            initialKwArgs = ', ' + initialKwArgs
-        self.addFilteredChunk('%(functionName)s(_callArgVal%(ID)s%(initialKwArgs)s)' % locals())
-        self.addChunk('del _callArgVal%(ID)s' % locals())
-        self.addChunk('## END CALL REGION: '
-                      + ID
-                      + ' of ' + functionName
-                      + ' at line %s, col %s' % lineCol + ' in the source.')
+        self.addChunk('_call_arg{0} = _call{0}.response().getvalue()'.format(call_id))
+        self.addChunk('del _call{0}'.format(call_id))
+
+        args = (', ' + args).strip()
+        self.addFilteredChunk(
+            '{function_name}(_call_arg{call_id}{args})'.format(
+                function_name=function_name,
+                call_id=call_id,
+                args=args,
+            )
+        )
+        self.addChunk('del _call_arg{0}'.format(call_id))
+        self.addChunk(
+            '## END CALL REGION: {call_id} of {function_name} '
+            'at line {line}, col {col}.'.format(
+                call_id=call_id,
+                function_name=function_name,
+                line=line,
+                col=col,
+            )
+        )
         self.addChunk('')
-        self._callRegionsStack.pop()  # attrib of current methodCompiler
-
-    nextFilterRegionID = nextCacheID
 
     def setFilter(self, filter_name):
-        filter_id = self.nextFilterRegionID()
-        filter_details = FilterDetails(filter_id, filter_name)
-        self._filterRegionsStack.append(
-            (filter_id, filter_details)
-        )
+        filter_id = self.next_id()
+        self._filterRegionsStack.append(filter_id)
 
         self.addChunk('_orig_filter{0} = _filter'.format(filter_id))
         if filter_name.lower() == 'none':
             self.addChunk('_filter = self._CHEETAH__initialFilter')
         else:
-            # is string representing the name of a builtin filter
             self.addChunk(
                 '_filter = '
                 'self._CHEETAH__currentFilter = '
@@ -490,43 +478,30 @@ class MethodCompiler(GenUtils):
             )
 
     def closeFilterBlock(self):
-        filter_id = self._filterRegionsStack.pop()[0]
+        filter_id = self._filterRegionsStack.pop()
         self.addChunk(
             '_filter = self._CHEETAH__currentFilter = _orig_filter{0}'.format(
                 filter_id,
             )
         )
 
-    def isClassMethod(self):
-        return '@classmethod' in self._decorators
-
-    def isStaticMethod(self):
-        return '@staticmethod' in self._decorators
-
     def _addAutoSetupCode(self):
         self.addChunk(self._initialMethodComment)
 
-        if not self.isClassMethod() and not self.isStaticMethod():
-            self.addChunk('trans = self.transaction')
-            self.addChunk('if not trans:')
-            self.indent()
-            self.addChunk('self.transaction = trans = DummyTransaction()')
-            self.addChunk('_dummyTrans = True')
-            self.dedent()
-            self.addChunk('else: _dummyTrans = False')
-        else:
-            self.addChunk('trans = DummyTransaction()')
-            self.addChunk('_dummyTrans = True')
+        self.addChunk('trans = self.transaction')
+        self.addChunk('if not trans:')
+        self.indent()
+        self.addChunk('self.transaction = trans = DummyTransaction()')
+        self.addChunk('_dummyTrans = True')
+        self.dedent()
+        self.addChunk('else:')
+        self.indent()
+        self.addChunk('_dummyTrans = False')
+        self.dedent()
         self.addChunk('write = trans.response().write')
         if self.setting('useNameMapper'):
-            if not self.isClassMethod() and not self.isStaticMethod():
-                self.addChunk('SL = self._CHEETAH__searchList')
-            else:
-                self.addChunk('SL = []')
-        if self.isClassMethod() or self.isStaticMethod():
-            self.addChunk('_filter = lambda x, **kwargs: unicode(x)')
-        else:
-            self.addChunk('_filter = self._CHEETAH__currentFilter')
+            self.addChunk('SL = self._CHEETAH__searchList')
+        self.addChunk('_filter = self._CHEETAH__currentFilter')
         self.addChunk('')
         self.addChunk("#" * 40)
         self.addChunk('## START - generated method body')
@@ -539,21 +514,17 @@ class MethodCompiler(GenUtils):
         self.addChunk('')
 
         if not self._isGenerator:
-            self.addStop()
+            self.addChunk('if _dummyTrans:')
+            self.indent()
+            self.addChunk('self.transaction = None')
+            self.addChunk('return trans.response().getvalue()')
+            self.dedent()
+            self.addChunk('else:')
+            self.indent()
+            self.addChunk('return NO_CONTENT')
+            self.dedent()
         self.addChunk('')
 
-    def addStop(self):
-        no_content = 'NO_CONTENT'
-        self.addChunk('if _dummyTrans:')
-        self.indent()
-        self.addChunk('self.transaction = None')
-        self.addChunk('return trans.response().getvalue()')
-        self.dedent()
-        self.addChunk('else:')
-        self.indent()
-        self.addChunk('return %s' % no_content)
-        self.dedent()
-
     def addMethArg(self, name, defVal=None):
         self._argStringList.append((name, defVal))
 
@@ -561,11 +532,6 @@ class MethodCompiler(GenUtils):
         argStringChunks = []
         for arg in self._argStringList:
             chunk = arg[0]
-            if chunk == 'self' and self.isClassMethod():
-                chunk = 'cls'
-            if chunk == 'self' and self.isStaticMethod():
-                # Skip the "self" method for @staticmethod decorators
-                continue
             if arg[1] is not None:
                 chunk += '=' + arg[1]
             argStringChunks.append(chunk)
@@ -590,11 +556,9 @@ class ClassCompiler(GenUtils):
 
     def __init__(self, className, mainMethodName='respond',
                  moduleCompiler=None,
-                 fileName=None,
                  settingsManager=None):
 
         self._settingsManager = settingsManager
-        self._fileName = fileName
         self._className = className
         self._moduleCompiler = moduleCompiler
         self._mainMethodName = mainMethodName
@@ -605,7 +569,6 @@ class ClassCompiler(GenUtils):
         self._baseClass = 'Template'
         # printed after methods in the gen class def:
         self._generatedAttribs = []
-        self._blockMetaData = {}
         methodCompiler = self._spawnMethodCompiler(
             mainMethodName,
             '## CHEETAH: main method generated for this template'
@@ -646,10 +609,9 @@ class ClassCompiler(GenUtils):
         self._mainMethodName = methodName
 
     def _spawnMethodCompiler(self, methodName, initialMethodComment):
-        klass = self.methodCompilerClass
         decorators = self._decoratorsForNextMethod or []
         self._decoratorsForNextMethod = []
-        methodCompiler = klass(
+        methodCompiler = self.methodCompilerClass(
             methodName,
             classCompiler=self,
             initialMethodComment=initialMethodComment,
@@ -683,13 +645,13 @@ class ClassCompiler(GenUtils):
     def _finishedMethods(self):
         return self._finishedMethodsList
 
-    def addDecorator(self, decoratorExpr):
+    def addDecorator(self, decorator_expr):
         """Set the decorator to be used with the next method in the source.
 
         See _spawnMethodCompiler() and MethodCompiler for the details of how
         this is used.
         """
-        self._decoratorsForNextMethod.append(decoratorExpr)
+        self._decoratorsForNextMethod.append(decorator_expr)
 
     def addAttribute(self, attribExpr):
         self._generatedAttribs.append(attribExpr)
@@ -892,12 +854,6 @@ class LegacyCompiler(SettingsManager, GenUtils):
         self.updateSettingsFromConfigStr(settingsStr)
         self._parser.configureParser()
 
-    def addModuleGlobal(self, line):
-        """Adds a line of global module code.  It is inserted after the import
-        statements and Cheetah default module constants.
-        """
-        self._moduleConstants.append(line)
-
     def addImportStatement(self, impStatement):
         settings = self.settings()
         if not self._methodBodyChunks or settings.get('useLegacyImportMode'):
@@ -915,9 +871,6 @@ class LegacyCompiler(SettingsManager, GenUtils):
         self._getActiveClassCompiler().addAttribute(attribName + ' =' + expr)
 
     def addComment(self, comm):
-        if re.match(r'#+$', comm):      # skip bar comments
-            return
-
         for line in comm.splitlines():
             self.addMethComment(line)
 
